@@ -4,13 +4,12 @@ import uuid
 
 from django.conf import settings
 from django.db import transaction
-from django.db.models import UUIDField, CharField, UniqueConstraint, Q
+from django.db.models import UUIDField, CharField, UniqueConstraint, Q, TextField
 from django.forms import model_to_dict
 
 from isc_common import setAttr, delAttr
 from isc_common.auth.http.LoginRequets import LoginRequest
 from isc_common.auth.models.user import User
-from isc_common.fields.description_field import DescriptionField
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_tree_grid_manager import CommonTreeGridManager
@@ -153,6 +152,7 @@ class MessagesManager(CommonTreeGridManager):
                 for to_whom_id in to_whom:
                     setAttr(data_clone, 'to_whom_id', to_whom_id)
                     setAttr(data_clone, 'guid', uuid.uuid4())
+                    delAttr(data_clone, 'id')
                     res = super().create(**data_clone)
 
                     if isinstance(messageFileIds, list):
@@ -349,7 +349,7 @@ class Messages(Hierarcy):
     checksum = CharField(max_length=255)
     guid = UUIDField(blank=True, null=True)
     importance = ForeignKeyProtect(Messages_importance, blank=True, null=True)
-    message = DescriptionField(null=False, blank=False)
+    message = TextField(null=False, blank=False)
     state = ForeignKeyCascade(Messages_state)
     theme = ForeignKeyProtect(Messages_theme)
     to_whom = ForeignKeyCascade(User, related_name='user_msg_to_whom')
