@@ -4,7 +4,7 @@ import urllib.request
 from django.conf import settings
 from django.http import HttpResponse
 
-from kaf_pas.common.UploadItem import UploadItem
+from isc_common.common.UploadItem import UploadItem
 from tracker.models.messages_files import Messages_files
 
 
